@@ -2,8 +2,7 @@ from .data_frames import *
 from .data_sources import *
 from .events import *
 from .exceptions import *
-from .file_manager import *
 from .tools import *
 from .view import *
 
-__all__ = ["data_frames", "data_sources", "events", "exceptions", "file_manager", "tools", "view"]
+__all__ = ["data_frames", "data_sources", "events", "exceptions", "tools", "view"]
